@@ -7,8 +7,11 @@ from flask_ease.utils import (
     Depends,
     Security,
     HTTPException,
-    Form
+    Form,
+    File,
+    MultipartForm,
+    status
 )
 from flask_ease.auth_schemes import OAuth2PasswordBearer
 
-__version__ = '0.1.5'
+__version__ = '0.1.8'
